from numbers import Real
from datadog_api_client.v2.model.metric_intake_type import MetricIntakeType
from datadog_api_client.v2.model.metric_point import MetricPoint
from datadog_api_client.v2.model.metric_resource import MetricResource
from datadog_api_client.v2.model.metric_series import MetricSeries

class Metric:
    name: str
    type: MetricIntakeType
    host: str
    tags: set
    kwargs: dict

    def __init__(
        self,
        name: str,
        type: MetricIntakeType,
        host: str = None,
        env: str = None,
        source: str = None,
        service: str = None,
        tags: set = None,
    ) -> None: ...
    def metric(self, timestamp: int, value: Real, tags: set = None) -> MetricSeries: ...

class GaugeMetric(Metric):
    def __init__(
        self, name: str, host: str = None, env: str = None, source: str = None, service: str = None, tags: set = None
    ) -> None: ...



import threading
import queue

from datadog_api_client.v2.model.metric_series import MetricSeries

class Worker(threading.Thread):
    api_key: str
    site: str
    queue: queue.SimpleQueue
    shutdown_event: threading.Event

    def __init__(
        self,
        name_index: int,
        api_key: str,
        site: str,
        queue: queue.SimpleQueue,
        shutdown_event: threading.Event,
        *args,
        **kwargs,
    ) -> None: ...
    def run(self):
        items: list[MetricSeries]



import click
from datadog_api_client import ApiClient, Configuration
from datadog_api_client.v1.api.authentication_api import AuthenticationApi
from datadog_api_client.exceptions import ForbiddenException

from .load_configuration import get_datadog_configuration


def validate_api_key():
    datadog_configuration = get_datadog_configuration()
    configuration = Configuration(
        api_key=dict(apiKeyAuth=datadog_configuration["api_key"]),
        server_variables=dict(site=datadog_configuration["site"]),
    )
    with ApiClient(configuration) as api_client:
        api_instance = AuthenticationApi(api_client)
        try:
            response = api_instance.validate()
        except ForbiddenException:
            return False
        except Exception:
            return None
    return response.valid


@click.command()
def validate_api_key_cli():
    result = validate_api_key()
    if result is None:
        print("Error occurred. Please try again later.")
    elif result:
        print("api_key is OK")
    else:
        print("api_key not valid")



import threading
import time
import queue

from datadog_api_client import Configuration, ApiClient
from datadog_api_client.v2.api.metrics_api import MetricsApi
from datadog_api_client.v2.model.metric_payload import MetricPayload
from netlink.logging import logger


class Worker(threading.Thread):
    def __init__(self, name_index, api_key, site, queue, shutdown_event, *args, **kwargs):
        super(Worker, self).__init__(name=f"datadog-{name_index}", *args, **kwargs)
        self.api_key = api_key
        self.site = site
        self.queue = queue
        self.shutdown_event = shutdown_event

    def run(self):
        logger.debug(f"Starting Datadog worker {self.name} ({self.native_id})")
        configuration = Configuration(api_key=dict(apiKeyAuth=self.api_key), server_variables=dict(site=self.site))
        items = []
        send_now = False
        while not self.shutdown_event.is_set():
            try:
                items.append(self.queue.get(timeout=1))
            except queue.Empty:
                send_now = True
            if len(items) >= 100 or send_now:
                if items:
                    logger.debug(f"Sending {len(items)} items to Datadog")
                    with ApiClient(configuration) as api_client:
                        try:
                            response = MetricsApi(api_client).submit_metrics(body=MetricPayload(series=items))
                            if response.errors:
                                for i in response.errors:
                                    logger.error(f"Datadog response: {i}")
                        except Exception as e:
                            logger.error(f"Got: {e.args}")
                            queue_size = self.queue.qsize()
                            logger.debug(f"putting {len(items)} back -- queue length before {self.queue.qsize()}")
                            for item in items:
                                self.queue.put(item)
                            logger.debug(
                                f"Put {len(items)} back into queue. Queue length before {queue_size}, after {self.queue.qsize()}"
                            )
                            time.sleep(10)
                        items.clear()
                send_now = False



from datetime import datetime
from datadog_api_client.v2.model.metric_intake_type import MetricIntakeType
from datadog_api_client.v2.model.metric_point import MetricPoint
from datadog_api_client.v2.model.metric_resource import MetricResource
from datadog_api_client.v2.model.metric_series import MetricSeries

from netlink.logging import logger


class Metric:
    def __init__(self, name, type, host=None, env=None, source=None, service=None, tags=None):
        logger.debug(f"Initializing metric {name}")
        logger.trace(f"type: {type}, host: {host}, env: {env}, source: {source}, service: {service}, tags: {tags}")
        self.name = name
        self.type = type
        self.host = host
        self.tags = set()
        if env:
            self.tags.add(f"env:{env}")
        if source:
            self.tags.add(f"source:{source}")
        if service:
            self.tags.add(f"service:{service}")
        self.tags = self.tags.union(tags or set())
        self.kwargs = dict(metric=self.name, type=self.type)
        if self.host:
            self.kwargs["resources"] = [MetricResource(name=self.host, type="host")]

    def metric(self, timestamp, value, tags=None):
        logger.debug(
            f'Metric {self.name}: {value} at {datetime.fromtimestamp(timestamp).strftime("%Y-%m-%dT%H:%M:%SZ")}'
        )
        kwargs = self.kwargs.copy()
        tags = self.tags.union(tags or set())
        if tags:
            logger.trace("Tags: " + ", ".join(tags))
            kwargs["tags"] = list(tags)
        return MetricSeries(
            points=[
                MetricPoint(timestamp=timestamp, value=value),
            ],
            **kwargs,
        )


class GaugeMetric(Metric):
    def __init__(self, name, host=None, env=None, source=None, service=None, tags=None):
        super(GaugeMetric, self).__init__(name, MetricIntakeType.GAUGE, host, env, source, service, tags)



import yaml
from netlink.logging import logger


def get_datadog_configuration():
    """Read file 'datadog.yaml' in <cwd>/conf.d"""
    logger.verbose("Reading Datadog configuration")
    with open("conf.d/datadog.yaml", "r", encoding="utf-8-sig") as f:
        datadog_configuration = yaml.safe_load(f)
    logger.trace(datadog_configuration)
    return datadog_configuration



# -*- coding: utf-8 -*-
from setuptools import setup

packages = \
['core']

package_data = \
{'': ['*']}

install_requires = \
['PyYAML', 'datadog-api-client', 'netlink-logging']

entry_points = \
{'console_scripts': ['validate_api_key = '
                     'netlink.datadog.core.validate_api_key:validate_api_key_cli']}

setup_kwargs = {
    'name': 'netlink-datadog-core',
    'version': '0.0.4',
    'description': 'Integration for Datadog (Core)',
    'long_description': '# netlink-datadog-core\n\nCore of Integration for Datadog\n\nProviding a wrapper of the [datadog-api-client](https://pypi.org/project/datadog-api-client/).\n\n# Utilities\n\n- validate_api_key\n\n# Classes\n\n## Metric\n\n### \\_\\_init\\_\\_\n\n  - `name` **str** - Name of metric\n  - `type` [MetricIntakeType](https://datadoghq.dev/datadog-api-client-ruby/DatadogAPIClient/V2/MetricIntakeType.html) \n  - `host` optional - **str** - will be added as resource type host\n  - `env`  **str** - Tag\n  - `source` **str** - Tag\n  - `service` **str** - Tag\n  - `tags` **set** - custom tags\n\n### metric\n\nReturns a [MetricSeries](https://datadoghq.dev/datadog-api-client-ruby/DatadogAPIClient/V2/MetricSeries.html)\n  \n  - `timestamp`\n  - `value`\n  - `tags` **set** - additional custom tags\n\n## GaugeMetric(Metric)\n\n### \\_\\_init\\_\\_\n\n  - `name` **str** - Name of metric\n  - `host` optional - **str** - will be added as resource type host\n  - `env`  **str** - Tag\n  - `source` **str** - Tag\n  - `service` **str** - Tag\n  - `tags` **set** - custom tags\n\n### metric\n\nReturns a [MetricSeries](https://datadoghq.dev/datadog-api-client-ruby/DatadogAPIClient/V2/MetricSeries.html)\n  \n  - `timestamp`\n  - `value`\n  - `tags` **set** - additional custom tags\n\n## Worker(threading.Thread)\n\nSends metrics to Datadog received in queue.\n\n### \\_\\_init\\_\\_\n\n  - `name_index` **int** used to create thread name\n  - `api_key` **str** Datadog api key\n  - `site` **str** Datadog site\n  - `queue` **queue.SimpleQueue**\n  - `shutdown_event` **threading.Event**\n  ',
    'author': 'Bernhard Radermacher',
    'author_email': 'bernhard.radermacher@netlink-consulting.com',
    'maintainer': None,
    'maintainer_email': None,
    'url': 'https://gitlab.com/netlink_python/netlink-datadog-core',
    'packages': packages,
    'package_data': package_data,
    'install_requires': install_requires,
    'entry_points': entry_points,
    'python_requires': '>=3.7,<3.11',
}


setup(**setup_kwargs)
